==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/WebCore/html/ImageInputType.h <==
/*
 * Copyright (C) 2010 Google Inc. All rights reserved.
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 * Copyright (C) 2012 Samsung Electronics. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ImageInputType_h
#define ImageInputType_h

#include "BaseButtonInputType.h"
#include "IntPoint.h"

namespace WebCore {

class ImageInputType final : public BaseButtonInputType {
public:
    explicit ImageInputType(HTMLInputElement&);

private:
    virtual const AtomicString& formControlType() const override;
    virtual bool isFormDataAppendable() const override;
    virtual bool appendFormData(FormDataList&, bool) const override;
    virtual bool supportsValidation() const override;
    virtual RenderPtr<RenderElement> createInputRenderer(PassRef<RenderStyle>) override;
    virtual void handleDOMActivateEvent(Event*) override;
    virtual void altAttributeChanged() override;
    virtual void srcAttributeChanged() override;
    virtual void attach() override;
    virtual bool shouldRespectAlignAttribute() override;
    virtual bool canBeSuccessfulSubmitButton() override;
    virtual bool isImageButton() const override;
    virtual bool isEnumeratable() override;
    virtual bool shouldRespectHeightAndWidthAttributes() override;
    virtual unsigned height() const override;
    virtual unsigned width() const override;

    IntPoint m_clickLocation; // Valid only during HTMLFormElement::prepareForSubmission().
};

} // namespace WebCore

#endif // ImageInputType_h

==> webkitgtk-2.13.2.tar.xz: webkitgtk-2.13.2/Source/WebCore/html/ImageInputType.h <==
/*
 * Copyright (C) 2010 Google Inc. All rights reserved.
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 * Copyright (C) 2012 Samsung Electronics. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef ImageInputType_h
#define ImageInputType_h

#include "BaseButtonInputType.h"
#include "IntPoint.h"

namespace WebCore {

class ImageInputType final : public BaseButtonInputType {
public:
    explicit ImageInputType(HTMLInputElement&);

private:
    const AtomicString& formControlType() const override;
    bool isFormDataAppendable() const override;
    bool appendFormData(FormDataList&, bool) const override;
    bool supportsValidation() const override;
    RenderPtr<RenderElement> createInputRenderer(RenderStyle&&) override;
    void handleDOMActivateEvent(Event*) override;
    void altAttributeChanged() override;
    void srcAttributeChanged() override;
    void attach() override;
    bool shouldRespectAlignAttribute() override;
    bool canBeSuccessfulSubmitButton() override;
    bool isImageButton() const override;
    bool isEnumeratable() override;
    bool shouldRespectHeightAndWidthAttributes() override;
    unsigned height() const override;
    unsigned width() const override;

    IntPoint m_clickLocation; // Valid only during HTMLFormElement::prepareForSubmission().
};

} // namespace WebCore

#endif // ImageInputType_h
